@@ -1,4 +1,7 @@
-pub struct ListSome<F: ListFn> { pub first: F::Item, pub next: F }
+pub struct ListSome<F: ListFn> {
+    pub first: F::Item,
+    pub next: F,
+}
 
 /// A list.
 pub enum ListState<F: ListFn> {
@@ -7,6 +10,12 @@ pub enum ListState<F: ListFn> {
     End(F::End),
 }
 
+impl<F: ListFn> ListState<F> {
+    pub fn some(first: F::Item, next: F) -> Self {
+        ListState::Some(ListSome { first, next })
+    }
+}
+
 /// A function which returns a list.
 pub trait ListFn: Sized {
     /// A list item type.
